@@ -1,6 +1,6 @@
 {- git-annex key/value backends
  -
- - Copyright 2010 Joey Hess <joey@kitenet.net>
+ - Copyright 2010,2013 Joey Hess <joey@kitenet.net>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -10,20 +10,21 @@ module Backend (
 	orderedList,
 	genKey,
 	lookupFile,
+	isAnnexLink,
 	chooseBackend,
 	lookupBackendName,
 	maybeLookupBackendName
 ) where
 
-import System.Posix.Files
-
 import Common.Annex
-import Config
 import qualified Annex
 import Annex.CheckAttr
+import Annex.CatFile
+import Annex.Link
 import Types.Key
 import Types.KeySource
 import qualified Types.Backend as B
+import Config
 
 -- When adding a new backend, import it here and add it to the list.
 import qualified Backend.SHA
@@ -39,21 +40,21 @@ orderedList = do
 	l <- Annex.getState Annex.backends -- list is cached here
 	if not $ null l
 		then return l
-		else handle =<< Annex.getState Annex.forcebackend
-	where
-		handle Nothing = standard
-		handle (Just "") = standard
-		handle (Just name) = do
-			l' <- (lookupBackendName name :) <$> standard
-			Annex.changeState $ \s -> s { Annex.backends = l' }
-			return l'
-		standard = parseBackendList <$> getConfig (annexConfig "backends") ""
-		parseBackendList [] = list
-		parseBackendList s = map lookupBackendName $ words s
+		else do
+			f <- Annex.getState Annex.forcebackend
+			case f of
+				Just name | not (null name) ->
+					return [lookupBackendName name]
+				_ -> do
+					l' <- gen . annexBackends <$> Annex.getGitConfig
+					Annex.changeState $ \s -> s { Annex.backends = l' }
+					return l'
+  where
+	gen [] = list
+	gen l = map lookupBackendName l
 
 {- Generates a key for a file, trying each backend in turn until one
- - accepts it.
- -}
+ - accepts it. -}
 genKey :: KeySource -> Maybe Backend -> Annex (Maybe (Key, Backend))
 genKey source trybackend = do
 	bs <- orderedList
@@ -66,50 +67,54 @@ genKey' (b:bs) source = do
 	case r of
 		Nothing -> genKey' bs source
 		Just k -> return $ Just (makesane k, b)
-	where
-		-- keyNames should not contain newline characters.
-		makesane k = k { keyName = map fixbadchar (keyName k) }
-		fixbadchar c
-			| c == '\n' = '_'
-			| otherwise = c
+  where
+	-- keyNames should not contain newline characters.
+	makesane k = k { keyName = map fixbadchar (keyName k) }
+	fixbadchar c
+		| c == '\n' = '_'
+		| otherwise = c
 
 {- Looks up the key and backend corresponding to an annexed file,
- - by examining what the file symlinks to. -}
+ - by examining what the file links to.
+ -
+ - In direct mode, there is often no link on disk, in which case
+ - the symlink is looked up in git instead. However, a real link
+ - on disk still takes precedence over what was committed to git in direct
+ - mode.
+ -}
 lookupFile :: FilePath -> Annex (Maybe (Key, Backend))
 lookupFile file = do
-	tl <- liftIO $ tryIO $ readSymbolicLink file
-	case tl of
-		Left _ -> return Nothing
-		Right l -> makekey l
-	where
-		makekey l = maybe (return Nothing) (makeret l) (fileKey $ takeFileName l)
-		makeret l k = let bname = keyBackendName k in
-			case maybeLookupBackendName bname of
-				Just backend -> do
-					return $ Just (k, backend)
-				Nothing -> do
-					when (isLinkToAnnex l) $ warning $
-						"skipping " ++ file ++
-						" (unknown backend " ++
-						bname ++ ")"
-					return Nothing
+	mkey <- isAnnexLink file
+	case mkey of
+		Just key -> makeret key
+		Nothing -> ifM isDirect
+			( maybe (return Nothing) makeret =<< catKeyFile file
+			, return Nothing
+			)
+  where
+	makeret k = let bname = keyBackendName k in
+		case maybeLookupBackendName bname of
+			Just backend -> return $ Just (k, backend)
+			Nothing -> do
+				warning $
+					"skipping " ++ file ++
+					" (unknown backend " ++ bname ++ ")"
+				return Nothing
 
 {- Looks up the backend that should be used for a file.
- - That can be configured on a per-file basis in the gitattributes file.
- -}
+ - That can be configured on a per-file basis in the gitattributes file. -}
 chooseBackend :: FilePath -> Annex (Maybe Backend)
 chooseBackend f = Annex.getState Annex.forcebackend >>= go
-	where
-		go Nothing =  maybeLookupBackendName <$>
-			checkAttr "annex.backend" f
-		go (Just _) = Just . Prelude.head <$> orderedList
+  where
+	go Nothing =  maybeLookupBackendName <$> checkAttr "annex.backend" f
+	go (Just _) = Just . Prelude.head <$> orderedList
 
 {- Looks up a backend by name. May fail if unknown. -}
 lookupBackendName :: String -> Backend
 lookupBackendName s = fromMaybe unknown $ maybeLookupBackendName s
-	where
-		unknown = error $ "unknown backend " ++ s
+  where
+	unknown = error $ "unknown backend " ++ s
 maybeLookupBackendName :: String -> Maybe Backend
 maybeLookupBackendName s = headMaybe matches
-	where
-		matches = filter (\b -> s == B.name b) list
+  where
+	matches = filter (\b -> s == B.name b) list
