@@ -8,25 +8,31 @@
 module Command.AddUnused where
 
 import Common.Annex
-import Logs.Unused
+import Logs.Location
 import Command
 import qualified Command.Add
+import Command.Unused (withUnusedMaps, UnusedMaps(..), startUnused)
 import Types.Key
 
 def :: [Command]
-def = [command "addunused" (paramRepeating paramNumRange)
-	seek "add back unused files"]
+def = [notDirect $ command "addunused" (paramRepeating paramNumRange)
+	seek SectionMaintenance "add back unused files"]
 
 seek :: [CommandSeek]
 seek = [withUnusedMaps start]
 
 start :: UnusedMaps -> Int -> CommandStart
-start = startUnused "addunused" perform (performOther "bad") (performOther "tmp")
+start = startUnused "addunused" perform
+	(performOther "bad")
+	(performOther "tmp")
 
 perform :: Key -> CommandPerform
-perform key = next $ Command.Add.cleanup file key True
-	where
-		file = "unused." ++ key2file key
+perform key = next $ do
+	logStatus key InfoPresent
+	Command.Add.addLink file key False
+	return True
+  where
+	file = "unused." ++ key2file key
 
 {- The content is not in the annex, but in another directory, and
  - it seems better to error out, rather than moving bad/tmp content into
