@@ -1,6 +1,6 @@
 {- git-annex command
  -
- - Copyright 2011 Joey Hess <joey@kitenet.net>
+ - Copyright 2011-2013 Joey Hess <joey@kitenet.net>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -54,17 +54,15 @@ start relaxed optfile pathdepth s = go $ fromMaybe bad $ parseURI s
 	bad = fromMaybe (error $ "bad url " ++ s) $
 		parseURI $ escapeURIString isUnescapedInURI s
 	go url = do
-		let file = fromMaybe (url2file url pathdepth) optfile
+		pathmax <- liftIO $ fileNameLengthLimit "."
+		let file = fromMaybe (url2file url pathdepth pathmax) optfile
 		showStart "addurl" file
 		next $ perform relaxed s file
 
 perform :: Bool -> String -> FilePath -> CommandPerform
 perform relaxed url file = ifAnnexed file addurl geturl
   where
-	geturl = do
-		liftIO $ createDirectoryIfMissing True (parentDir file)
-		ifM (Annex.getState Annex.fast <||> pure relaxed)
-			( nodownload relaxed url file , download url file )
+	geturl = next $ addUrlFile relaxed url file
 	addurl (key, _backend)
 		| relaxed = do
 			setUrlPresent key url
@@ -76,26 +74,39 @@ perform relaxed url file = ifAnnexed file addurl geturl
 					setUrlPresent key url
 					next $ return True
 				, do
-					warning $ "failed to verify url: " ++ url
+					warning $ "failed to verify url exists: " ++ url
 					stop
 				)
 
-download :: String -> FilePath -> CommandPerform
+addUrlFile :: Bool -> String -> FilePath -> Annex Bool
+addUrlFile relaxed url file = do
+	liftIO $ createDirectoryIfMissing True (parentDir file)
+	ifM (Annex.getState Annex.fast <||> pure relaxed)
+		( nodownload relaxed url file
+		, do
+			showAction $ "downloading " ++ url ++ " "
+			download url file
+		)
+
+download :: String -> FilePath -> Annex Bool
 download url file = do
-	showAction $ "downloading " ++ url ++ " "
 	dummykey <- genkey
 	tmp <- fromRepo $ gitAnnexTmpLocation dummykey
-	stopUnless (runtransfer dummykey tmp) $ do
-		backend <- chooseBackend file
-		let source = KeySource
-			{ keyFilename = file
-			, contentLocation = tmp
-			, inodeCache = Nothing
-			}
-		k <- genKey source backend
-		case k of
-			Nothing -> stop
-			Just (key, _) -> next $ cleanup url file key (Just tmp)
+	showOutput
+	ifM (runtransfer dummykey tmp)
+		( do
+			backend <- chooseBackend file
+			let source = KeySource
+				{ keyFilename = file
+				, contentLocation = tmp
+				, inodeCache = Nothing
+				}
+			k <- genKey source backend
+			case k of
+				Nothing -> return False
+				Just (key, _) -> cleanup url file key (Just tmp)
+		, return False
+		)
   where
 	{- Generate a dummy key to use for this download, before we can
 	 - examine the file and find its real key. This allows resuming
@@ -112,14 +123,14 @@ download url file = do
 				liftIO $ snd <$> Url.exists url headers
 			, return Nothing
 			)
-		return $ Backend.URL.fromUrl url size
+		Backend.URL.fromUrl url size
   	runtransfer dummykey tmp = 
 		Transfer.download webUUID dummykey (Just file) Transfer.forwardRetry $ const $ do
 			liftIO $ createDirectoryIfMissing True (parentDir tmp)
 			downloadUrl [url] tmp
 		
 
-cleanup :: String -> FilePath -> Key -> Maybe FilePath -> CommandCleanup
+cleanup :: String -> FilePath -> Key -> Maybe FilePath -> Annex Bool
 cleanup url file key mtmp = do
 	when (isJust mtmp) $
 		logStatus key InfoPresent
@@ -133,7 +144,7 @@ cleanup url file key mtmp = do
 	maybe noop (moveAnnex key) mtmp
 	return True
 
-nodownload :: Bool -> String -> FilePath -> CommandPerform
+nodownload :: Bool -> String -> FilePath -> Annex Bool
 nodownload relaxed url file = do
 	headers <- getHttpHeaders
 	(exists, size) <- if relaxed
@@ -141,15 +152,15 @@ nodownload relaxed url file = do
 		else liftIO $ Url.exists url headers
 	if exists
 		then do
-			let key = Backend.URL.fromUrl url size
-			next $ cleanup url file key Nothing
+			key <- Backend.URL.fromUrl url size
+			cleanup url file key Nothing
 		else do
 			warning $ "unable to access url: " ++ url
-			stop
+			return False
 
-url2file :: URI -> Maybe Int -> FilePath
-url2file url pathdepth = case pathdepth of
-	Nothing -> filesize $ escape fullurl
+url2file :: URI -> Maybe Int -> Int -> FilePath
+url2file url pathdepth pathmax = case pathdepth of
+	Nothing -> truncateFilePath pathmax $ escape fullurl
 	Just depth
 		| depth >= length urlbits -> frombits id
 		| depth > 0 -> frombits $ drop depth
@@ -158,7 +169,6 @@ url2file url pathdepth = case pathdepth of
   where
 	fullurl = uriRegName auth ++ uriPath url ++ uriQuery url
 	frombits a = intercalate "/" $ a urlbits
-	urlbits = map (filesize . escape) $ filter (not . null) $ split "/" fullurl
+	urlbits = map (truncateFilePath pathmax . escape) $ filter (not . null) $ split "/" fullurl
 	auth = fromMaybe (error $ "bad url " ++ show url) $ uriAuthority url
-	filesize = take 255
 	escape = replace "/" "_" . replace "?" "_"
