@@ -14,7 +14,7 @@ import qualified Git
 
 def :: [Command]
 def = [command "commit" paramNothing seek
-	"commits any staged changes to the git-annex branch"]
+	SectionPlumbing "commits any staged changes to the git-annex branch"]
 
 seek :: [CommandSeek]
 seek = [withNothing start]
@@ -22,8 +22,8 @@ seek = [withNothing start]
 start :: CommandStart
 start = next $ next $ do
 	Annex.Branch.commit "update"
-	_ <- runhook =<< (inRepo $ Git.hookPath "annex-content")
+	_ <- runhook <=< inRepo $ Git.hookPath "annex-content"
 	return True
-	where
-		runhook (Just hook) = liftIO $ boolSystem hook []
-		runhook Nothing = return True
+  where
+	runhook (Just hook) = liftIO $ boolSystem hook []
+	runhook Nothing = return True
