@@ -17,7 +17,7 @@ import qualified Data.Set as S
 
 def :: [Command]
 def = [command "dead" (paramRepeating paramRemote) seek
-	"hide a lost repository"]
+	SectionSetup "hide a lost repository"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
@@ -25,12 +25,16 @@ seek = [withWords start]
 start :: [String] -> CommandStart
 start ws = do
 	let name = unwords ws
-	showStart "dead " name
+	showStart "dead" name
 	u <- Remote.nameToUUID name
 	next $ perform u
 
 perform :: UUID -> CommandPerform
 perform uuid = do
+	markDead uuid
+	next $ return True
+
+markDead :: UUID -> Annex ()
+markDead uuid = do
 	trustSet uuid DeadTrusted
 	groupSet uuid S.empty
-	next $ return True
