@@ -21,43 +21,46 @@ import Annex.Wanted
 
 def :: [Command]
 def = [withOptions [fromOption] $ command "drop" paramPaths seek
-	"indicate content of files not currently wanted"]
+	SectionCommon "indicate content of files not currently wanted"]
 
 fromOption :: Option
 fromOption = Option.field ['f'] "from" paramRemote "drop content from a remote"
 
 seek :: [CommandSeek]
-seek = [withField fromOption Remote.byName $ \from ->
+seek = [withField fromOption Remote.byNameWithUUID $ \from ->
 	withFilesInGit $ whenAnnexed $ start from]
 
 start :: Maybe Remote -> FilePath -> (Key, Backend) -> CommandStart
-start from file (key, _) = autoCopiesWith file key (>) $ \numcopies ->
-	stopUnless (checkAuto $ wantDrop (Remote.uuid <$> from) (Just file)) $
+start from file (key, _) = checkDropAuto from file key $ \numcopies ->
+	stopUnless (checkAuto $ wantDrop False (Remote.uuid <$> from) (Just file)) $
 		case from of
-			Nothing -> startLocal file numcopies key
+			Nothing -> startLocal file numcopies key Nothing
 			Just remote -> do
 				u <- getUUID
 				if Remote.uuid remote == u
-					then startLocal file numcopies key
+					then startLocal file numcopies key Nothing
 					else startRemote file numcopies key remote
 
-startLocal :: FilePath -> Maybe Int -> Key -> CommandStart
-startLocal file numcopies key = stopUnless (inAnnex key) $ do
+startLocal :: FilePath -> Maybe Int -> Key -> Maybe Remote -> CommandStart
+startLocal file numcopies key knownpresentremote = stopUnless (inAnnex key) $ do
 	showStart "drop" file
-	next $ performLocal key numcopies
+	next $ performLocal key numcopies knownpresentremote
 
 startRemote :: FilePath -> Maybe Int -> Key -> Remote -> CommandStart
 startRemote file numcopies key remote = do
-	showStart "drop" file
+	showStart ("drop " ++ Remote.name remote) file
 	next $ performRemote key numcopies remote
 
-performLocal :: Key -> Maybe Int -> CommandPerform
-performLocal key numcopies = lockContent key $ do
+performLocal :: Key -> Maybe Int -> Maybe Remote -> CommandPerform
+performLocal key numcopies knownpresentremote = lockContent key $ do
 	(remotes, trusteduuids) <- Remote.keyPossibilitiesTrusted key
+	let trusteduuids' = case knownpresentremote of
+		Nothing -> trusteduuids
+		Just r -> nub (Remote.uuid r:trusteduuids)
 	untrusteduuids <- trustGet UnTrusted
-	let tocheck = Remote.remotesWithoutUUID remotes (trusteduuids++untrusteduuids)
-	stopUnless (canDropKey key numcopies trusteduuids tocheck []) $ do
-		whenM (inAnnex key) $ removeAnnex key
+	let tocheck = Remote.remotesWithoutUUID remotes (trusteduuids'++untrusteduuids)
+	stopUnless (canDropKey key numcopies trusteduuids' tocheck []) $ do
+		removeAnnex key
 		next $ cleanupLocal key
 
 performRemote :: Key -> Maybe Int -> Remote -> CommandPerform
@@ -76,8 +79,8 @@ performRemote key numcopies remote = lockContent key $ do
 	stopUnless (canDropKey key numcopies have tocheck [uuid]) $ do
 		ok <- Remote.removeKey remote key
 		next $ cleanupRemote key remote ok
-	where
-		uuid = Remote.uuid remote
+  where
+	uuid = Remote.uuid remote
 
 cleanupLocal :: Key -> CommandCleanup
 cleanupLocal key = do
@@ -86,10 +89,8 @@ cleanupLocal key = do
 
 cleanupRemote :: Key -> Remote -> Bool -> CommandCleanup
 cleanupRemote key remote ok = do
-	-- better safe than sorry: assume the remote dropped the key
-	-- even if it seemed to fail; the failure could have occurred
-	-- after it really dropped it
-	Remote.logStatus remote key InfoMissing
+	when ok $
+		Remote.logStatus remote key InfoMissing
 	return ok
 
 {- Checks specified remotes to verify that enough copies of a key exist to
@@ -105,21 +106,22 @@ canDropKey key numcopiesM have check skip = do
 			findCopies key need skip have check
 
 findCopies :: Key -> Int -> [UUID] -> [UUID] -> [Remote] -> Annex Bool
-findCopies key need skip = helper []
-	where
-		helper bad have []
-			| length have >= need = return True
-			| otherwise = notEnoughCopies key need have skip bad
-		helper bad have (r:rs)
-			| length have >= need = return True
-			| otherwise = do
-				let u = Remote.uuid r
-				let duplicate = u `elem` have
-				haskey <- Remote.hasKey r key
-				case (duplicate, haskey) of
-					(False, Right True) -> helper bad (u:have) rs
-					(False, Left _)     -> helper (r:bad) have rs
-					_                   -> helper bad have rs
+findCopies key need skip = helper [] []
+  where
+	helper bad missing have []
+		| length have >= need = return True
+		| otherwise = notEnoughCopies key need have (skip++missing) bad
+	helper bad missing have (r:rs)
+		| length have >= need = return True
+		| otherwise = do
+			let u = Remote.uuid r
+			let duplicate = u `elem` have
+			haskey <- Remote.hasKey r key
+			case (duplicate, haskey) of
+				(False, Right True)  -> helper bad missing (u:have) rs
+				(False, Left _)      -> helper (r:bad) missing have rs
+				(False, Right False) -> helper bad (u:missing) have rs
+				_                    -> helper bad missing have rs
 
 notEnoughCopies :: Key -> Int -> [UUID] -> [UUID] -> [Remote] -> Annex Bool
 notEnoughCopies key need have skip bad = do
@@ -130,8 +132,30 @@ notEnoughCopies key need have skip bad = do
 		" necessary copies"
 	Remote.showTriedRemotes bad
 	Remote.showLocations key (have++skip)
+		"Rather than dropping this file, try using: git annex move"
 	hint
 	return False
-	where
-		unsafe = showNote "unsafe"
-		hint = showLongNote "(Use --force to override this check, or adjust annex.numcopies.)"
+  where
+	unsafe = showNote "unsafe"
+	hint = showLongNote "(Use --force to override this check, or adjust annex.numcopies.)"
+
+{- In auto mode, only runs the action if there are enough copies
+ - copies on other semitrusted repositories.
+ -
+ - Passes any numcopies attribute of the file on to the action as an
+ - optimisation. -}
+checkDropAuto :: Maybe Remote -> FilePath -> Key -> (Maybe Int -> CommandStart) -> CommandStart
+checkDropAuto mremote file key a = do
+	numcopiesattr <- numCopies file
+	Annex.getState Annex.auto >>= auto numcopiesattr
+  where
+	auto numcopiesattr False = a numcopiesattr
+	auto numcopiesattr True = do
+		needed <- getNumCopies numcopiesattr
+		locs <- Remote.keyLocations key
+		uuid <- getUUID
+		let remoteuuid = fromMaybe uuid $ Remote.uuid <$> mremote
+		locs' <- trustExclude UnTrusted $ filter (/= remoteuuid) locs
+		if length locs' >= needed
+			then a numcopiesattr
+			else stop
