@@ -18,22 +18,31 @@ import qualified Command.Copy
 import qualified Command.Sync
 import qualified Command.Whereis
 import qualified Command.Fsck
+import GitAnnex.Options
+
+import System.Console.GetOpt
 
 def :: [Command]
-def = [noCommit $ noRepo showHelp $ dontCheck repoExists $
-	command "help" paramNothing seek "display help"]
+def = [noCommit $ noRepo showGeneralHelp $ dontCheck repoExists $
+	command "help" paramNothing seek SectionQuery "display help"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
 
 start :: [String] -> CommandStart
+start ["options"] = do
+	liftIO showCommonOptions
+	stop
 start _ = do
-	liftIO showHelp
+	liftIO showGeneralHelp
 	stop
 
-showHelp :: IO ()
-showHelp = liftIO $ putStrLn $ unlines
-	[ "The most commonly used git-annex commands are:"
+showCommonOptions :: IO ()
+showCommonOptions = putStrLn $ usageInfo "Common options:" options
+
+showGeneralHelp :: IO ()
+showGeneralHelp = putStrLn $ unlines
+	[ "The most frequently used git-annex commands are:"
 	, unlines $ map cmdline $ concat
 		[ Command.Init.def
 		, Command.Add.def
@@ -45,7 +54,9 @@ showHelp = liftIO $ putStrLn $ unlines
 		, Command.Whereis.def
 		, Command.Fsck.def
 		]
-	, "Run git-annex without any options for a complete command and option list."
+	, "Run 'git-annex' for a complete command list."
+	, "Run 'git-annex command --help' for help on a specific command."
+	, "Run `git annex help options' for a list of common options."
 	]
-	where
-		cmdline c = "\t" ++ cmdname c ++ "\t" ++ cmddesc c
+  where
+	cmdline c = "\t" ++ cmdname c ++ "\t" ++ cmddesc c
