@@ -7,19 +7,22 @@
 
 module Command.Import where
 
+import System.PosixCompat.Files
+
 import Common.Annex
 import Command
 import qualified Annex
 import qualified Command.Add
 
 def :: [Command]
-def = [command "import" paramPaths seek "move and add files from outside git working copy"]
+def = [notBareRepo $ command "import" paramPaths seek
+	SectionCommon "move and add files from outside git working copy"]
 
 seek :: [CommandSeek]
 seek = [withPathContents start]
 
 start :: (FilePath, FilePath) -> CommandStart
-start (srcfile, destfile) = notBareRepo $
+start (srcfile, destfile) =
 	ifM (liftIO $ isRegularFile <$> getSymbolicLinkStatus srcfile)
 		( do
 			showStart "import" destfile
@@ -33,7 +36,7 @@ perform srcfile destfile = do
 		unlessM (Annex.getState Annex.force) $
 			error $ "not overwriting existing " ++ destfile ++
 				" (use --force to override)"
- 
+
 	liftIO $ createDirectoryIfMissing True (parentDir destfile)
 	liftIO $ moveFile srcfile destfile
 	Command.Add.perform destfile
