@@ -13,15 +13,15 @@ import Annex.Content
 
 def :: [Command]
 def = [noCommit $ command "inannex" (paramRepeating paramKey) seek
-	"checks if keys are present in the annex"]
+	SectionPlumbing "checks if keys are present in the annex"]
 
 seek :: [CommandSeek]
 seek = [withKeys start]
 
 start :: Key -> CommandStart
 start key = inAnnexSafe key >>= dispatch
-	where
-		dispatch (Just True) = stop
-		dispatch (Just False) = exit 1
-		dispatch Nothing = exit 100
-		exit n = liftIO $ exitWith $ ExitFailure n
+  where
+	dispatch (Just True) = stop
+	dispatch (Just False) = exit 1
+	dispatch Nothing = exit 100
+	exit n = liftIO $ exitWith $ ExitFailure n
