@@ -13,7 +13,7 @@ import Init
 	
 def :: [Command]
 def = [dontCheck repoExists $
-	command "init" paramDesc seek "initialize git-annex"]
+	command "init" paramDesc seek SectionSetup "initialize git-annex"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
@@ -22,8 +22,8 @@ start :: [String] -> CommandStart
 start ws = do
 	showStart "init" description
 	next $ perform description
-	where
-		description = unwords ws
+  where
+	description = unwords ws
 
 perform :: String -> CommandPerform
 perform description = do
