@@ -7,20 +7,19 @@
 
 module Command.Semitrust where
 
+import Common.Annex
 import Command
 import qualified Remote
-import UUID
-import Trust
-import Messages
+import Logs.Trust
 
-command :: [Command]
-command = [repoCommand "semitrust" (paramRepeating paramRemote) seek
-	"return repository to default trust level"]
+def :: [Command]
+def = [command "semitrust" (paramRepeating paramRemote) seek
+	SectionSetup "return repository to default trust level"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
 
-start :: CommandStartWords
+start :: [String] -> CommandStart
 start ws = do
 	let name = unwords ws
 	showStart "semitrust" name
