@@ -9,10 +9,11 @@
 
 module Command.Status where
 
-import Control.Monad.State.Strict
+import "mtl" Control.Monad.State.Strict
 import qualified Data.Map as M
 import Text.JSON
 import Data.Tuple
+import System.PosixCompat.Files
 
 import Common.Annex
 import qualified Types.Backend as B
@@ -34,6 +35,8 @@ import Config
 import Utility.Percentage
 import Logs.Transfer
 import Types.TrustLevel
+import Types.FileMatcher
+import qualified Limit
 
 -- a named computation that produces a statistic
 type Stat = StatState (Maybe (String, StatState String))
@@ -56,28 +59,54 @@ data StatInfo = StatInfo
 type StatState = StateT StatInfo Annex
 
 def :: [Command]
-def = [command "status" paramNothing seek
-	"shows status information about the annex"]
+def = [command "status" paramPaths seek
+	SectionQuery "shows status information about the annex"]
 
 seek :: [CommandSeek]
-seek = [withNothing start]
+seek = [withWords start]
+
+start :: [FilePath] -> CommandStart
+start [] = do
+	globalStatus
+	stop
+start ps = do
+	mapM_ localStatus =<< filterM isdir ps
+	stop
+  where
+	isdir = liftIO . catchBoolIO . (isDirectory <$$> getFileStatus)
+
+globalStatus :: Annex ()
+globalStatus = do
+	fast <- Annex.getState Annex.fast
+	let stats = if fast
+		then global_fast_stats
+		else global_fast_stats ++ global_slow_stats
+	showCustom "status" $ do
+		evalStateT (mapM_ showStat stats) (StatInfo Nothing Nothing)
+		return True
+
+localStatus :: FilePath -> Annex ()
+localStatus dir = showCustom (unwords ["status", dir]) $ do
+	let stats = map (\s -> s dir) local_stats
+	evalStateT (mapM_ showStat stats) =<< getLocalStatInfo dir
+	return True
 
 {- Order is significant. Less expensive operations, and operations
  - that share data go together.
  -}
-fast_stats :: [Stat]
-fast_stats = 
+global_fast_stats :: [Stat]
+global_fast_stats = 
 	[ supported_backends
 	, supported_remote_types
+	, repository_mode
 	, remote_list Trusted
 	, remote_list SemiTrusted
 	, remote_list UnTrusted
-	, remote_list DeadTrusted
 	, transfer_list
 	, disk_size
 	]
-slow_stats :: [Stat]
-slow_stats = 
+global_slow_stats :: [Stat]
+global_slow_stats = 
 	[ tmp_size
 	, bad_data_size
 	, local_annex_keys
@@ -87,15 +116,14 @@ slow_stats =
 	, bloom_info
 	, backend_usage
 	]
-
-start :: CommandStart
-start = do
-	fast <- Annex.getState Annex.fast
-	let stats = if fast then fast_stats else fast_stats ++ slow_stats
-	showCustom "status" $ do
-		evalStateT (mapM_ showStat stats) (StatInfo Nothing Nothing)
-		return True
-	stop
+local_stats :: [FilePath -> Stat]
+local_stats =
+	[ local_dir
+	, const local_annex_keys
+	, const local_annex_size
+	, const known_annex_keys
+	, const known_annex_size
+	]
 
 stat :: String -> (String -> StatState String) -> Stat
 stat desc a = return $ Just (desc, a desc)
@@ -114,10 +142,10 @@ nojson a _ = a
 
 showStat :: Stat -> StatState ()
 showStat s = maybe noop calc =<< s
-	where
-		calc (desc, a) = do
-			(lift . showHeader) desc
-			lift . showRaw =<< a
+  where
+	calc (desc, a) = do
+		(lift . showHeader) desc
+		lift . showRaw =<< a
 
 supported_backends :: Stat
 supported_backends = stat "supported backends" $ json unwords $
@@ -127,15 +155,23 @@ supported_remote_types :: Stat
 supported_remote_types = stat "supported remote types" $ json unwords $
 	return $ map R.typename Remote.remoteTypes
 
+repository_mode :: Stat
+repository_mode = stat "repository mode" $ json id $ lift $
+	ifM isDirect 
+		( return "direct", return "indirect" )
+
 remote_list :: TrustLevel -> Stat
 remote_list level = stat n $ nojson $ lift $ do
 	us <- M.keys <$> (M.union <$> uuidMap <*> remoteMap Remote.name)
 	rs <- fst <$> trustPartition level us
 	s <- prettyPrintUUIDs n rs
 	return $ if null s then "0" else show (length rs) ++ "\n" ++ beginning s
-	where
-		n = showTrustLevel level ++ " repositories"
+  where
+	n = showTrustLevel level ++ " repositories"
 	
+local_dir :: FilePath -> Stat
+local_dir dir = stat "directory" $ json id $ return dir
+
 local_annex_size :: Stat
 local_annex_size = stat "local annex size" $ json id $
 	showSizeKeys <$> cachedPresentData
@@ -182,42 +218,42 @@ transfer_list = stat "transfers in progress" $ nojson $ lift $ do
 		then return "none"
 		else return $ multiLine $
 			map (\(t, i) -> line uuidmap t i) $ sort ts
-	where
-		line uuidmap t i = unwords
-			[ showLcDirection (transferDirection t) ++ "ing"
-			, fromMaybe (key2file $ transferKey t) (associatedFile i)
-			, if transferDirection t == Upload then "to" else "from"
-			, maybe (fromUUID $ transferUUID t) Remote.name $
-				M.lookup (transferUUID t) uuidmap
-			]
+  where
+	line uuidmap t i = unwords
+		[ showLcDirection (transferDirection t) ++ "ing"
+		, fromMaybe (key2file $ transferKey t) (associatedFile i)
+		, if transferDirection t == Upload then "to" else "from"
+		, maybe (fromUUID $ transferUUID t) Remote.name $
+			M.lookup (transferUUID t) uuidmap
+		]
 
 disk_size :: Stat
 disk_size = stat "available local disk space" $ json id $ lift $
 	calcfree
-		<$> getDiskReserve
+		<$> (annexDiskReserve <$> Annex.getGitConfig)
 		<*> inRepo (getDiskFree . gitAnnexDir)
-	where
-		calcfree reserve (Just have) = unwords
-			[ roughSize storageUnits False $ nonneg $ have - reserve
-			, "(+" ++ roughSize storageUnits False reserve
-			, "reserved)"
-			]
-			
-		calcfree _ _ = "unknown"
-		nonneg x
-			| x >= 0 = x
-			| otherwise = 0
+  where
+	calcfree reserve (Just have) = unwords
+		[ roughSize storageUnits False $ nonneg $ have - reserve
+		, "(+" ++ roughSize storageUnits False reserve
+		, "reserved)"
+		]			
+	calcfree _ _ = "unknown"
+
+	nonneg x
+		| x >= 0 = x
+		| otherwise = 0
 
 backend_usage :: Stat
 backend_usage = stat "backend usage" $ nojson $
 	calc
 		<$> (backendsKeys <$> cachedReferencedData)
 		<*> (backendsKeys <$> cachedPresentData)
-	where
-		calc x y = multiLine $
-			map (\(n, b) -> b ++ ": " ++ show n) $
-			reverse $ sort $ map swap $ M.toList $
-			M.unionWith (+) x y
+  where
+	calc x y = multiLine $
+		map (\(n, b) -> b ++ ": " ++ show n) $
+		reverse $ sort $ map swap $ M.toList $
+		M.unionWith (+) x y
 
 cachedPresentData :: StatState KeyData
 cachedPresentData = do
@@ -240,6 +276,26 @@ cachedReferencedData = do
 			put s { referencedData = Just v }
 			return v
 
+getLocalStatInfo :: FilePath -> Annex StatInfo
+getLocalStatInfo dir = do
+	matcher <- Limit.getMatcher
+	(presentdata, referenceddata) <-
+		Command.Unused.withKeysFilesReferencedIn dir initial
+			(update matcher)
+	return $ StatInfo (Just presentdata) (Just referenceddata)
+  where
+	initial = (emptyKeyData, emptyKeyData)
+	update matcher key file vs@(presentdata, referenceddata) =
+		ifM (matcher $ FileInfo file file)
+			( (,)
+				<$> ifM (inAnnex key)
+					( return $ addKey key presentdata
+					, return presentdata
+					)
+				<*> pure (addKey key referenceddata)
+			, return vs
+			)
+
 emptyKeyData :: KeyData
 emptyKeyData = KeyData 0 0 0 M.empty
 
@@ -249,43 +305,41 @@ foldKeys = foldl' (flip addKey) emptyKeyData
 addKey :: Key -> KeyData -> KeyData
 addKey key (KeyData count size unknownsize backends) =
 	KeyData count' size' unknownsize' backends'
-	where
-		{- All calculations strict to avoid thunks when repeatedly
-		 - applied to many keys. -}
-		!count' = count + 1
-		!backends' = M.insertWith' (+) (keyBackendName key) 1 backends
-		!size' = maybe size (+ size) ks
-		!unknownsize' = maybe (unknownsize + 1) (const unknownsize) ks
-		ks = keySize key
+  where
+	{- All calculations strict to avoid thunks when repeatedly
+	 - applied to many keys. -}
+	!count' = count + 1
+	!backends' = M.insertWith' (+) (keyBackendName key) 1 backends
+	!size' = maybe size (+ size) ks
+	!unknownsize' = maybe (unknownsize + 1) (const unknownsize) ks
+	ks = keySize key
 
 showSizeKeys :: KeyData -> String
 showSizeKeys d = total ++ missingnote
-	where
-		total = roughSize storageUnits False $ sizeKeys d
-		missingnote
-			| unknownSizeKeys d == 0 = ""
-			| otherwise = aside $
-				"+ " ++ show (unknownSizeKeys d) ++
-				" keys of unknown size"
+  where
+	total = roughSize storageUnits False $ sizeKeys d
+	missingnote
+		| unknownSizeKeys d == 0 = ""
+		| otherwise = aside $
+			"+ " ++ show (unknownSizeKeys d) ++
+			" keys of unknown size"
 
 staleSize :: String -> (Git.Repo -> FilePath) -> Stat
 staleSize label dirspec = go =<< lift (Command.Unused.staleKeys dirspec)
-	where
-		go [] = nostat
-		go keys = onsize =<< sum <$> keysizes keys
-		onsize 0 = nostat
-		onsize size = stat label $
-			json (++ aside "clean up with git-annex unused") $
-				return $ roughSize storageUnits False size
-		keysizes keys = map (fromIntegral . fileSize) <$> stats keys
-		stats keys = do
-			dir <- lift $ fromRepo dirspec
-			liftIO $ forM keys $ \k ->
-				getFileStatus (dir </> keyFile k)
+  where
+	go [] = nostat
+	go keys = onsize =<< sum <$> keysizes keys
+	onsize 0 = nostat
+	onsize size = stat label $
+		json (++ aside "clean up with git-annex unused") $
+			return $ roughSize storageUnits False size
+	keysizes keys = map (fromIntegral . fileSize) <$> stats keys
+	stats keys = do
+		dir <- lift $ fromRepo dirspec
+		liftIO $ forM keys $ \k -> getFileStatus (dir </> keyFile k)
 
 aside :: String -> String
 aside s = " (" ++ s ++ ")"
 
 multiLine :: [String] -> String
 multiLine = concatMap (\l -> "\n\t" ++ l)
-
