@@ -1,7 +1,7 @@
 {- git-annex command
  -
- - Copyright 2011 Joey Hess <joey@kitenet.net>
  - Copyright 2011 Joachim Breitner <mail@joachim-breitner.de>
+ - Copyright 2011,2012 Joey Hess <joey@kitenet.net>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -14,8 +14,9 @@ import qualified Remote
 import qualified Annex
 import qualified Annex.Branch
 import qualified Annex.Queue
-import Annex.Content
+import Annex.Direct
 import Annex.CatFile
+import Annex.Link
 import qualified Git.Command
 import qualified Git.LsFiles as LsFiles
 import qualified Git.Merge
@@ -27,13 +28,13 @@ import qualified Types.Remote
 import qualified Remote.Git
 import Types.Key
 import Config
+import Annex.ReplaceFile
 
-import qualified Data.ByteString.Lazy as L
 import Data.Hash.MD5
 
 def :: [Command]
 def = [command "sync" (paramOptional (paramRepeating paramRemote))
-	[seek] "synchronize local repository with remotes"]
+	[seek] SectionCommon "synchronize local repository with remotes"]
 
 -- syncing involves several operations, any of which can independently fail
 seek :: CommandSeek
@@ -48,8 +49,8 @@ seek rs = do
 		, [ pushLocal branch ]
 		, [ pushRemote remote branch | remote <- remotes ]
 		]
-	where
-		nobranch = error "no branch is checked out"
+  where
+	nobranch = error "no branch is checked out"
 
 syncBranch :: Git.Ref -> Git.Ref
 syncBranch = Git.Ref.under "refs/heads/synced/"
@@ -59,47 +60,55 @@ remoteBranch remote = Git.Ref.under $ "refs/remotes/" ++ Remote.name remote
 
 syncRemotes :: [String] -> Annex [Remote]
 syncRemotes rs = ifM (Annex.getState Annex.fast) ( nub <$> pickfast , wanted )
-	where
-		pickfast = (++) <$> listed <*> (good =<< fastest <$> available)
-		wanted
-			| null rs = good =<< concat . Remote.byCost <$> available
-			| otherwise = listed
-		listed = do
-			l <- catMaybes <$> mapM (Remote.byName . Just) rs
-			let s = filter Remote.specialRemote l
-			unless (null s) $
-				error $ "cannot sync special remotes: " ++
-					unwords (map Types.Remote.name s)
-			return l
-		available = filter (not . Remote.specialRemote)
-			<$> (filterM (repoSyncable . Types.Remote.repo)
-				=<< Remote.enabledRemoteList)
-		good = filterM $ Remote.Git.repoAvail . Types.Remote.repo
-		fastest = fromMaybe [] . headMaybe . Remote.byCost
+  where
+	pickfast = (++) <$> listed <*> (good =<< fastest <$> available)
+	wanted
+		| null rs = good =<< concat . Remote.byCost <$> available
+		| otherwise = listed
+	listed = do
+		l <- catMaybes <$> mapM (Remote.byName . Just) rs
+		let s = filter Remote.specialRemote l
+		unless (null s) $
+			error $ "cannot sync special remotes: " ++
+				unwords (map Types.Remote.name s)
+		return l
+	available = filter (not . Remote.specialRemote)
+		. filter (remoteAnnexSync . Types.Remote.gitconfig)
+		<$> Remote.remoteList
+	good = filterM $ Remote.Git.repoAvail . Types.Remote.repo
+	fastest = fromMaybe [] . headMaybe . Remote.byCost
 
 commit :: CommandStart
-commit = do
-	showStart "commit" ""
-	next $ next $ do
+commit = next $ next $ do
+	ifM isDirect
+		( do
+			void $ stageDirect
+			runcommit []
+		, runcommit [Param "-a"]
+		)
+  where
+	runcommit ps = do
+		showStart "commit" ""
 		showOutput
 		Annex.Branch.commit "update"
 		-- Commit will fail when the tree is clean, so ignore failure.
-		_ <- inRepo $ Git.Command.runBool "commit"
-			[Param "-a", Param "-m", Param "git-annex automatic sync"]
+		let params = (Param "commit") : ps ++
+			[Param "-m", Param "git-annex automatic sync"]
+		_ <- inRepo $ tryIO . Git.Command.runQuiet params
 		return True
 
 mergeLocal :: Git.Ref -> CommandStart
 mergeLocal branch = go =<< needmerge
-	where
-		syncbranch = syncBranch branch
-		needmerge = do
-			unlessM (inRepo $ Git.Ref.exists syncbranch) $
-				inRepo $ updateBranch syncbranch
-			inRepo $ Git.Branch.changed branch syncbranch
-		go False = stop
-		go True = do
-			showStart "merge" $ Git.Ref.describe syncbranch
-			next $ next $ mergeFrom syncbranch
+  where
+	syncbranch = syncBranch branch
+	needmerge = do
+		unlessM (inRepo $ Git.Ref.exists syncbranch) $
+			inRepo $ updateBranch syncbranch
+		inRepo $ Git.Branch.changed branch syncbranch
+	go False = stop
+	go True = do
+		showStart "merge" $ Git.Ref.describe syncbranch
+		next $ next $ mergeFrom syncbranch
 
 pushLocal :: Git.Ref -> CommandStart
 pushLocal branch = do
@@ -109,11 +118,12 @@ pushLocal branch = do
 updateBranch :: Git.Ref -> Git.Repo -> IO ()
 updateBranch syncbranch g = 
 	unlessM go $ error $ "failed to update " ++ show syncbranch
-	where
-		go = Git.Command.runBool "branch"
-			[ Param "-f"
-			, Param $ show $ Git.Ref.base syncbranch
-			] g
+  where
+	go = Git.Command.runBool
+		[ Param "branch"
+		, Param "-f"
+		, Param $ show $ Git.Ref.base syncbranch
+		] g
 
 pullRemote :: Remote -> Git.Ref -> CommandStart
 pullRemote remote branch = do
@@ -122,13 +132,14 @@ pullRemote remote branch = do
 		showOutput
 		stopUnless fetch $
 			next $ mergeRemote remote (Just branch)
-	where
-		fetch = inRepo $ Git.Command.runBool "fetch"
-			[Param $ Remote.name remote]
+  where
+	fetch = inRepo $ Git.Command.runBool
+		[Param "fetch", Param $ Remote.name remote]
 
 {- The remote probably has both a master and a synced/master branch.
  - Which to merge from? Well, the master has whatever latest changes
- - were committed, while the synced/master may have changes that some
+ - were committed (or pushed changes, if this is a bare remote),
+ - while the synced/master may have changes that some
  - other remote synced to this remote. So, merge them both. -}
 mergeRemote :: Remote -> (Maybe Git.Ref) -> CommandCleanup
 mergeRemote remote b = case b of
@@ -136,49 +147,81 @@ mergeRemote remote b = case b of
 		branch <- inRepo Git.Branch.currentUnsafe
 		all id <$> (mapM merge $ branchlist branch)
 	Just _ -> all id <$> (mapM merge =<< tomerge (branchlist b))
-	where
-		merge = mergeFrom . remoteBranch remote
-		tomerge branches = filterM (changed remote) branches
-		branchlist Nothing = []
-		branchlist (Just branch) = [branch, syncBranch branch]
+  where
+	merge = mergeFrom . remoteBranch remote
+	tomerge branches = filterM (changed remote) branches
+	branchlist Nothing = []
+	branchlist (Just branch) = [branch, syncBranch branch]
 
 pushRemote :: Remote -> Git.Ref -> CommandStart
 pushRemote remote branch = go =<< needpush
-	where
-		needpush = anyM (newer remote) [syncBranch branch, Annex.Branch.name]
-		go False = stop
-		go True = do
-			showStart "push" (Remote.name remote)
-			next $ next $ do
-				showOutput
-				inRepo $ pushBranch remote branch
+  where
+	needpush = anyM (newer remote) [syncBranch branch, Annex.Branch.name]
+	go False = stop
+	go True = do
+		showStart "push" (Remote.name remote)
+		next $ next $ do
+			showOutput
+			inRepo $ pushBranch remote branch
 
+{- If the remote is a bare git repository, it's best to push the branch
+ - directly to it. On the other hand, if it's not bare, pushing to the
+ - checked out branch will fail, and this is why we use the syncBranch.
+ -
+ - Git offers no way to tell if a remote is bare or not, so both methods
+ - are tried.
+ -
+ - The direct push is likely to spew an ugly error message, so stderr is
+ - elided. Since progress is output to stderr too, the sync push is done
+ - first, and actually sends the data. Then the direct push is tried,
+ - with stderr discarded, to update the branch ref on the remote.
+ -}
 pushBranch :: Remote -> Git.Ref -> Git.Repo -> IO Bool
-pushBranch remote branch g =
-	Git.Command.runBool "push"
-		[ Param $ Remote.name remote
+pushBranch remote branch g = tryIO directpush `after` syncpush
+  where
+	syncpush = Git.Command.runBool (pushparams (refspec branch)) g
+	directpush = Git.Command.runQuiet (pushparams (show $ Git.Ref.base branch)) g
+	pushparams b =
+		[ Param "push"
+		, Param $ Remote.name remote
 		, Param $ refspec Annex.Branch.name
-		, Param $ refspec branch
-		] g
-	where
-		refspec b = concat 
-			[ show $ Git.Ref.base b
-			,  ":"
-			, show $ Git.Ref.base $ syncBranch b
-			]
+		, Param b
+		]
+	refspec b = concat 
+		[ show $ Git.Ref.base b
+		,  ":"
+		, show $ Git.Ref.base $ syncBranch b
+		]
 
 mergeAnnex :: CommandStart
 mergeAnnex = do
 	void $ Annex.Branch.forceUpdate
 	stop
 
+{- Merges from a branch into the current branch. -}
 mergeFrom :: Git.Ref -> Annex Bool
 mergeFrom branch = do
 	showOutput
-	ok <- inRepo $ Git.Merge.mergeNonInteractive branch
-	if ok
-		then return ok
-		else resolveMerge
+	ifM isDirect
+		( maybe go godirect =<< inRepo Git.Branch.current
+		, go
+		)
+  where
+	go = runmerge $ inRepo $ Git.Merge.mergeNonInteractive branch
+	godirect currbranch = do
+		old <- inRepo $ Git.Ref.sha currbranch
+		d <- fromRepo gitAnnexMergeDir
+		r <- runmerge $ inRepo $ mergeDirect d branch
+		new <- inRepo $ Git.Ref.sha currbranch
+		case (old, new) of
+			(Just oldsha, Just newsha) ->
+				mergeDirectCleanup d oldsha newsha
+			_ -> noop
+		return r
+	runmerge a = ifM (a)
+		( return True
+		, resolveMerge
+		)
 
 {- Resolves a conflicted merge. It's important that any conflicts be
  - resolved in a way that itself avoids later merge conflicts, since
@@ -200,50 +243,61 @@ resolveMerge = do
 	top <- fromRepo Git.repoPath
 	(fs, cleanup) <- inRepo (LsFiles.unmerged [top])
 	merged <- all id <$> mapM resolveMerge' fs
+	void $ liftIO cleanup
+
+	(deleted, cleanup2) <- inRepo (LsFiles.deleted [top])
+	unless (null deleted) $
+		Annex.Queue.addCommand "rm" [Params "--quiet -f --"] deleted
+	void $ liftIO cleanup2
+	
 	when merged $ do
 		Annex.Queue.flush
-		void $ inRepo $ Git.Command.runBool "commit"
-			[Param "-m", Param "git-annex automatic merge conflict fix"]
-	void $ liftIO cleanup
+		void $ inRepo $ Git.Command.runBool
+			[ Param "commit"
+			, Param "-m"
+			, Param "git-annex automatic merge conflict fix"
+			]
 	return merged
 
 resolveMerge' :: LsFiles.Unmerged -> Annex Bool
 resolveMerge' u
 	| issymlink LsFiles.valUs && issymlink LsFiles.valThem =
 		withKey LsFiles.valUs $ \keyUs ->
-		withKey LsFiles.valThem $ \keyThem -> go keyUs keyThem
-	| otherwise = return False
-	where
-		go keyUs keyThem
-			| keyUs == keyThem = do
-				makelink keyUs
-				return True
-			| otherwise = do
-				liftIO $ nukeFile file
+			withKey LsFiles.valThem $ \keyThem -> do
+				ifM isDirect
+					( maybe noop (\k -> removeDirect k file) keyUs
+					, liftIO $ nukeFile file
+					)
 				Annex.Queue.addCommand "rm" [Params "--quiet -f --"] [file]
-				makelink keyUs
-				makelink keyThem
-				return True
-		file = LsFiles.unmergedFile u
-		issymlink select = any (select (LsFiles.unmergedBlobType u) ==)
-			[Just SymlinkBlob, Nothing]
-		makelink (Just key) = do
-			let dest = mergeFile file key
-			l <- calcGitLink dest key
-			liftIO $ do
-				nukeFile dest
-				createSymbolicLink l dest
-			Annex.Queue.addCommand "add" [Param "--force", Param "--"] [dest]
-		makelink _ = noop
-		withKey select a = do
-			let msha = select $ LsFiles.unmergedSha u
-			case msha of
-				Nothing -> a Nothing
-				Just sha -> do
-					key <- fileKey . takeFileName
-						. encodeW8 . L.unpack 
-						<$> catObject sha
-					maybe (return False) (a . Just) key
+				go keyUs keyThem
+	| otherwise = return False
+  where
+	go keyUs keyThem
+		| keyUs == keyThem = do
+			makelink keyUs
+			return True
+		| otherwise = do
+			makelink keyUs
+			makelink keyThem
+			return True
+	file = LsFiles.unmergedFile u
+	issymlink select = any (select (LsFiles.unmergedBlobType u) ==)
+		[Just SymlinkBlob, Nothing]
+	makelink (Just key) = do
+		let dest = mergeFile file key
+		l <- inRepo $ gitAnnexLink dest key
+		replaceFile dest $ makeAnnexLink l
+		stageSymlink dest =<< hashSymlink l
+		whenM (isDirect) $
+			toDirect key dest
+	makelink _ = noop
+	withKey select a = do
+		let msha = select $ LsFiles.unmergedSha u
+		case msha of
+			Nothing -> a Nothing
+			Just sha -> do
+				key <- catKey sha
+				maybe (return False) (a . Just) key
 
 {- The filename to use when resolving a conflicted merge of a file,
  - that points to a key.
@@ -262,13 +316,13 @@ mergeFile :: FilePath -> Key -> FilePath
 mergeFile file key
 	| doubleconflict = go $ key2file key
 	| otherwise = go $ shortHash $ key2file key
-	where
-		varmarker = ".variant-"
-		doubleconflict = varmarker `isSuffixOf` (dropExtension file)
-		go v = takeDirectory file
-			</> dropExtension (takeFileName file)
-			++ varmarker ++ v
-			++ takeExtension file
+  where
+	varmarker = ".variant-"
+	doubleconflict = varmarker `isInfixOf` file
+	go v = takeDirectory file
+		</> dropExtension (takeFileName file)
+		++ varmarker ++ v
+		++ takeExtension file
 		
 shortHash :: String -> String
 shortHash = take 4 . md5s . md5FilePath
