@@ -7,20 +7,19 @@
 
 module Command.Trust where
 
+import Common.Annex
 import Command
 import qualified Remote
-import Trust
-import UUID
-import Messages
+import Logs.Trust
 
-command :: [Command]
-command = [repoCommand "trust" (paramRepeating paramRemote) seek
-	"trust a repository"]
+def :: [Command]
+def = [command "trust" (paramRepeating paramRemote) seek
+	SectionSetup "trust a repository"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
 
-start :: CommandStartWords
+start :: [String] -> CommandStart
 start ws = do
 	let name = unwords ws
 	showStart "trust" name
