@@ -11,10 +11,11 @@ import Common.Annex
 import Command
 import qualified Build.SysConfig as SysConfig
 import Annex.Version
+import BuildFlags
 
 def :: [Command]
 def = [noCommit $ noRepo showPackageVersion $ dontCheck repoExists $
-	command "version" paramNothing seek "show version info"]
+	command "version" paramNothing seek SectionQuery "show version info"]
 
 seek :: [CommandSeek]
 seek = [withNothing start]
@@ -26,11 +27,11 @@ start = do
 		showPackageVersion
 		putStrLn $ "local repository version: " ++ fromMaybe "unknown" v
 		putStrLn $ "default repository version: " ++ defaultVersion
-		putStrLn $ "supported repository versions: " ++ vs supportedVersions
-		putStrLn $ "upgrade supported from repository versions: " ++ vs upgradableVersions
+		putStrLn $ "supported repository versions: " ++ unwords supportedVersions
+		putStrLn $ "upgrade supported from repository versions: " ++ unwords upgradableVersions
 	stop
-	where
-		vs = join " "
 
 showPackageVersion :: IO ()
-showPackageVersion = putStrLn $ "git-annex version: " ++ SysConfig.packageversion
+showPackageVersion = do
+	putStrLn $ "git-annex version: " ++ SysConfig.packageversion
+	putStrLn $ "build flags: " ++ unwords buildFlags
