@@ -8,9 +8,12 @@
 module Git.LsFiles (
 	inRepo,
 	notInRepo,
+	deleted,
+	modified,
 	staged,
 	stagedNotDeleted,
-	changedUnstaged,
+	stagedOthersDetails,
+	stagedDetails,
 	typeChanged,
 	typeChangedStaged,
 	Conflicting(..),
@@ -31,12 +34,26 @@ inRepo l = pipeNullSplit $ Params "ls-files --cached -z --" : map File l
 {- Scans for files at the specified locations that are not checked into git. -}
 notInRepo :: Bool -> [FilePath] -> Repo -> IO ([FilePath], IO Bool)
 notInRepo include_ignored l repo = pipeNullSplit params repo
-	where
-		params = [Params "ls-files --others"] ++ exclude ++
-			[Params "-z --"] ++ map File l
-		exclude
-			| include_ignored = []
-			| otherwise = [Param "--exclude-standard"]
+  where
+	params = [Params "ls-files --others"] ++ exclude ++
+		[Params "-z --"] ++ map File l
+	exclude
+		| include_ignored = []
+		| otherwise = [Param "--exclude-standard"]
+
+{- Returns a list of files in the specified locations that have been
+ - deleted. -}
+deleted :: [FilePath] -> Repo -> IO ([FilePath], IO Bool)
+deleted l repo = pipeNullSplit params repo
+  where
+	params = [Params "ls-files --deleted -z --"] ++ map File l
+
+{- Returns a list of files in the specified locations that have been
+ - modified. -}
+modified :: [FilePath] -> Repo -> IO ([FilePath], IO Bool)
+modified l repo = pipeNullSplit params repo
+  where
+	params = [Params "ls-files --modified -z --"] ++ map File l
 
 {- Returns a list of all files that are staged for commit. -}
 staged :: [FilePath] -> Repo -> IO ([FilePath], IO Bool)
@@ -49,15 +66,33 @@ stagedNotDeleted = staged' [Param "--diff-filter=ACMRT"]
 
 staged' :: [CommandParam] -> [FilePath] -> Repo -> IO ([FilePath], IO Bool)
 staged' ps l = pipeNullSplit $ prefix ++ ps ++ suffix
-	where
-		prefix = [Params "diff --cached --name-only -z"]
-		suffix = Param "--" : map File l
+  where
+	prefix = [Params "diff --cached --name-only -z"]
+	suffix = Param "--" : map File l
 
-{- Returns a list of files that have unstaged changes. -}
-changedUnstaged :: [FilePath] -> Repo -> IO ([FilePath], IO Bool)
-changedUnstaged l = pipeNullSplit params
-	where
-		params = Params "diff --name-only -z --" : map File l
+{- Returns details about files that are staged in the index,
+ - as well as files not yet in git. Skips ignored files. -}
+stagedOthersDetails :: [FilePath] -> Repo -> IO ([(FilePath, Maybe Sha)], IO Bool)
+stagedOthersDetails = stagedDetails' [Params "--others --exclude-standard"]
+
+{- Returns details about all files that are staged in the index. -}
+stagedDetails :: [FilePath] -> Repo -> IO ([(FilePath, Maybe Sha)], IO Bool)
+stagedDetails = stagedDetails' []
+
+{- Gets details about staged files, including the Sha of their staged
+ - contents. -}
+stagedDetails' :: [CommandParam] -> [FilePath] -> Repo -> IO ([(FilePath, Maybe Sha)], IO Bool)
+stagedDetails' ps l repo = do
+	(ls, cleanup) <- pipeNullSplit params repo
+	return (map parse ls, cleanup)
+  where
+	params = Params "ls-files --stage -z" : ps ++ 
+		Param "--" : map File l
+	parse s
+		| null file = (s, Nothing)
+		| otherwise = (file, extractSha $ take shaSize $ drop 7 metadata)
+	  where
+		(metadata, file) = separate (== '\t') s
 
 {- Returns a list of the files in the specified locations that are staged
  - for commit, and whose type has changed. -}
@@ -77,9 +112,9 @@ typeChanged' ps l repo = do
 	let top = repoPath repo
 	cwd <- getCurrentDirectory
 	return (map (\f -> relPathDirToFile cwd $ top </> f) fs, cleanup)
-	where
-		prefix = [Params "diff --name-only --diff-filter=T -z"]
-		suffix = Param "--" : map File l
+  where
+	prefix = [Params "diff --name-only --diff-filter=T -z"]
+	suffix = Param "--" : (if null l then [File "."] else map File l)
 
 {- A item in conflict has two possible values.
  - Either can be Nothing, when that side deleted the file. -}
@@ -102,14 +137,14 @@ data Unmerged = Unmerged
  -   1 = old version, can be ignored
  -   2 = us
  -   3 = them
- - If a line is omitted, that side deleted the file.
+ - If a line is omitted, that side removed the file.
  -}
 unmerged :: [FilePath] -> Repo -> IO ([Unmerged], IO Bool)
 unmerged l repo = do
 	(fs, cleanup) <- pipeNullSplit params repo
 	return (reduceUnmerged [] $ catMaybes $ map parseUnmerged fs, cleanup)
-	where
-		params = Params "ls-files --unmerged -z --" : map File l
+  where
+	params = Params "ls-files --unmerged -z --" : map File l
 
 data InternalUnmerged = InternalUnmerged
 	{ isus :: Bool
@@ -120,37 +155,39 @@ data InternalUnmerged = InternalUnmerged
 
 parseUnmerged :: String -> Maybe InternalUnmerged
 parseUnmerged s
-	| null file || length ws < 3 = Nothing
-	| otherwise = do
-		stage <- readish (ws !! 2) :: Maybe Int
-		unless (stage == 2 || stage == 3) $
-			fail undefined -- skip stage 1
-		blobtype <- readBlobType (ws !! 0)
-		sha <- extractSha (ws !! 1)
-		return $ InternalUnmerged (stage == 2) file (Just blobtype) (Just sha)
-	where
-		(metadata, file) = separate (== '\t') s
-		ws = words metadata
+	| null file = Nothing
+	| otherwise = case words metadata of
+		(rawblobtype:rawsha:rawstage:_) -> do
+			stage <- readish rawstage :: Maybe Int
+			unless (stage == 2 || stage == 3) $
+				fail undefined -- skip stage 1
+			blobtype <- readBlobType rawblobtype
+			sha <- extractSha rawsha
+			return $ InternalUnmerged (stage == 2) file
+				(Just blobtype) (Just sha)
+		_ -> Nothing
+  where
+	(metadata, file) = separate (== '\t') s
 
 reduceUnmerged :: [Unmerged] -> [InternalUnmerged] -> [Unmerged]
 reduceUnmerged c [] = c
 reduceUnmerged c (i:is) = reduceUnmerged (new:c) rest
-	where
-		(rest, sibi) = findsib i is
-		(blobtypeA, blobtypeB, shaA, shaB)
-			| isus i    = (iblobtype i, iblobtype sibi, isha i, isha sibi)
-			| otherwise = (iblobtype sibi, iblobtype i, isha sibi, isha i)
-		new = Unmerged
-			{ unmergedFile = ifile i
-			, unmergedBlobType = Conflicting blobtypeA blobtypeB
-			, unmergedSha = Conflicting shaA shaB
-			}
-		findsib templatei [] = ([], deleted templatei)
-		findsib templatei (l:ls)
-			| ifile l == ifile templatei = (ls, l)
-			| otherwise = (l:ls, deleted templatei)
-		deleted templatei = templatei
-			{ isus = not (isus templatei)
-			, iblobtype = Nothing
-			, isha = Nothing
-			}
+  where
+	(rest, sibi) = findsib i is
+	(blobtypeA, blobtypeB, shaA, shaB)
+		| isus i    = (iblobtype i, iblobtype sibi, isha i, isha sibi)
+		| otherwise = (iblobtype sibi, iblobtype i, isha sibi, isha i)
+	new = Unmerged
+		{ unmergedFile = ifile i
+		, unmergedBlobType = Conflicting blobtypeA blobtypeB
+		, unmergedSha = Conflicting shaA shaB
+		}
+	findsib templatei [] = ([], removed templatei)
+	findsib templatei (l:ls)
+		| ifile l == ifile templatei = (ls, l)
+		| otherwise = (l:ls, removed templatei)
+	removed templatei = templatei
+		{ isus = not (isus templatei)
+		, iblobtype = Nothing
+		, isha = Nothing
+		}
