@@ -8,6 +8,7 @@
 module Git.LsTree (
 	TreeItem(..),
 	lsTree,
+	lsTreeFiles,
 	parseLsTree
 ) where
 
@@ -18,6 +19,7 @@ import System.Posix.Types
 import Common
 import Git
 import Git.Command
+import Git.Sha
 import qualified Git.Filename
 
 data TreeItem = TreeItem
@@ -27,10 +29,17 @@ data TreeItem = TreeItem
 	, file :: FilePath
 	} deriving Show
 
-{- Lists the contents of a Ref -}
+{- Lists the complete contents of a tree, with lazy output. -}
 lsTree :: Ref -> Repo -> IO [TreeItem]
-lsTree t repo = map parseLsTree <$>
-	pipeNullSplitZombie [Params "ls-tree --full-tree -z -r --", File $ show t] repo
+lsTree t repo = map parseLsTree <$> pipeNullSplitZombie ps repo
+  where
+  	ps = [Params "ls-tree --full-tree -z -r --", File $ show t]
+
+{- Lists specified files in a tree. -}
+lsTreeFiles :: Ref -> [FilePath] -> Repo -> IO [TreeItem]
+lsTreeFiles t fs repo = map parseLsTree <$> pipeNullSplitStrict ps repo
+  where
+  	ps = [Params "ls-tree -z --", File $ show t] ++ map File fs
 
 {- Parses a line of ls-tree output.
  - (The --long format is not currently supported.) -}
@@ -41,11 +50,11 @@ parseLsTree l = TreeItem
 	, sha = s
 	, file = Git.Filename.decode f
 	}
-	where
-		-- l = <mode> SP <type> SP <sha> TAB <file>
-		-- All fields are fixed, so we can pull them out of
-		-- specific positions in the line.
-		(m, past_m) = splitAt 7 l
-		(t, past_t) = splitAt 4 past_m
-		(s, past_s) = splitAt 40 $ Prelude.tail past_t
-		f = Prelude.tail past_s
+  where
+	-- l = <mode> SP <type> SP <sha> TAB <file>
+	-- All fields are fixed, so we can pull them out of
+	-- specific positions in the line.
+	(m, past_m) = splitAt 7 l
+	(t, past_t) = splitAt 4 past_m
+	(s, past_s) = splitAt shaSize $ Prelude.tail past_t
+	f = Prelude.tail past_s
