@@ -20,12 +20,16 @@ import qualified Git.Config
 import qualified Git.Construct
 import qualified Git.Ref
 import Config
+import Config.Cost
 import Remote.Helper.Ssh
 import Remote.Helper.Special
 import Remote.Helper.Encryptable
 import Crypto
 import Data.ByteString.Lazy.UTF8 (fromString)
 import Data.Digest.Pure.SHA
+import Utility.UserInfo
+import Annex.Content
+import Utility.Metered
 
 type BupRepo = String
 
@@ -37,35 +41,42 @@ remote = RemoteType {
 	setup = bupSetup
 }
 
-gen :: Git.Repo -> UUID -> Maybe RemoteConfig -> Annex Remote
-gen r u c = do
-	buprepo <- getRemoteConfig r "buprepo" (error "missing buprepo")
-	cst <- remoteCost r (if bupLocal buprepo then semiCheapRemoteCost else expensiveRemoteCost)
+gen :: Git.Repo -> UUID -> RemoteConfig -> RemoteGitConfig -> Annex Remote
+gen r u c gc = do
 	bupr <- liftIO $ bup2GitRemote buprepo
+	cst <- remoteCost gc $
+		if bupLocal buprepo
+			then nearlyCheapRemoteCost
+			else expensiveRemoteCost
 	(u', bupr') <- getBupUUID bupr u
 	
+	let new = Remote
+		{ uuid = u'
+		, cost = cst
+		, name = Git.repoDescribe r
+		, storeKey = store new buprepo
+		, retrieveKeyFile = retrieve buprepo
+		, retrieveKeyFileCheap = retrieveCheap buprepo
+		, removeKey = remove
+		, hasKey = checkPresent r bupr'
+		, hasKeyCheap = bupLocal buprepo
+		, whereisKey = Nothing
+		, config = c
+		, repo = r
+		, gitconfig = gc
+		, localpath = if bupLocal buprepo && not (null buprepo)
+			then Just buprepo
+			else Nothing
+		, remotetype = remote
+		, globallyAvailable = not $ bupLocal buprepo
+		, readonly = False
+		}
 	return $ encryptableRemote c
-		(storeEncrypted r buprepo)
+		(storeEncrypted new buprepo)
 		(retrieveEncrypted buprepo)
-		Remote
-			{ uuid = u'
-			, cost = cst
-			, name = Git.repoDescribe r
- 			, storeKey = store r buprepo
-			, retrieveKeyFile = retrieve buprepo
-			, retrieveKeyFileCheap = retrieveCheap buprepo
-			, removeKey = remove
-			, hasKey = checkPresent r bupr'
-			, hasKeyCheap = bupLocal buprepo
-			, whereisKey = Nothing
-			, config = c
-			, repo = r
-			, localpath = if bupLocal buprepo && not (null buprepo)
-				then Just buprepo
-				else Nothing
-			, remotetype = remote
-			, readonly = False
-			}
+		new
+  where
+	buprepo = fromMaybe (error "missing buprepo") $ remoteAnnexBupRepo gc
 
 bupSetup :: UUID -> RemoteConfig -> Annex RemoteConfig
 bupSetup u c = do
@@ -105,30 +116,28 @@ pipeBup params inh outh = do
 		ExitSuccess -> return True
 		_ -> return False
 
-bupSplitParams :: Git.Repo -> BupRepo -> Key -> CommandParam -> Annex [CommandParam]
+bupSplitParams :: Remote -> BupRepo -> Key -> [CommandParam] -> Annex [CommandParam]
 bupSplitParams r buprepo k src = do
-	o <- getRemoteConfig r "bup-split-options" ""
-	let os = map Param $ words o
+	let os = map Param $ remoteAnnexBupSplitOptions $ gitconfig r
 	showOutput -- make way for bup output
 	return $ bupParams "split" buprepo 
-		(os ++ [Param "-n", Param (bupRef k), src])
+		(os ++ [Param "-n", Param (bupRef k)] ++ src)
 
-store :: Git.Repo -> BupRepo -> Key -> AssociatedFile -> MeterUpdate -> Annex Bool
-store r buprepo k _f _p = do
-	src <- inRepo $ gitAnnexLocation k
-	params <- bupSplitParams r buprepo k (File src)
+store :: Remote -> BupRepo -> Key -> AssociatedFile -> MeterUpdate -> Annex Bool
+store r buprepo k _f _p = sendAnnex k (rollback k buprepo) $ \src -> do
+	params <- bupSplitParams r buprepo k [File src]
 	liftIO $ boolSystem "bup" params
 
-storeEncrypted :: Git.Repo -> BupRepo -> (Cipher, Key) -> Key -> MeterUpdate -> Annex Bool
-storeEncrypted r buprepo (cipher, enck) k _p = do
-	src <- inRepo $ gitAnnexLocation k
-	params <- bupSplitParams r buprepo enck (Param "-")
-	liftIO $ catchBoolIO $
-		withEncryptedHandle cipher (L.readFile src) $ \h ->
-			pipeBup params (Just h) Nothing
+storeEncrypted :: Remote -> BupRepo -> (Cipher, Key) -> Key -> MeterUpdate -> Annex Bool
+storeEncrypted r buprepo (cipher, enck) k _p =
+	sendAnnex k (rollback enck buprepo) $ \src -> do
+		params <- bupSplitParams r buprepo enck []
+		liftIO $ catchBoolIO $
+			encrypt (getGpgOpts r) cipher (feedFile src) $ \h ->
+				pipeBup params (Just h) Nothing
 
-retrieve :: BupRepo -> Key -> AssociatedFile -> FilePath -> Annex Bool
-retrieve buprepo k _f d = do
+retrieve :: BupRepo -> Key -> AssociatedFile -> FilePath -> MeterUpdate -> Annex Bool
+retrieve buprepo k _f d _p = do
 	let params = bupParams "join" buprepo [Param $ bupRef k]
 	liftIO $ catchBoolIO $ do
 		tofile <- openFile d WriteMode
@@ -137,20 +146,35 @@ retrieve buprepo k _f d = do
 retrieveCheap :: BupRepo -> Key -> FilePath -> Annex Bool
 retrieveCheap _ _ _ = return False
 
-retrieveEncrypted :: BupRepo -> (Cipher, Key) -> Key -> FilePath -> Annex Bool
-retrieveEncrypted buprepo (cipher, enck) _ f = liftIO $ catchBoolIO $
+retrieveEncrypted :: BupRepo -> (Cipher, Key) -> Key -> FilePath -> MeterUpdate -> Annex Bool
+retrieveEncrypted buprepo (cipher, enck) _ f _p = liftIO $ catchBoolIO $
 	withHandle StdoutHandle createProcessSuccess p $ \h -> do
-		withDecryptedContent cipher (L.hGetContents h) $ L.writeFile f
+		decrypt cipher (\toh -> L.hPut toh =<< L.hGetContents h) $
+			readBytes $ L.writeFile f
 		return True
-	where
-		params = bupParams "join" buprepo [Param $ bupRef enck]
-		p = proc "bup" $ toCommand params
+  where
+	params = bupParams "join" buprepo [Param $ bupRef enck]
+	p = proc "bup" $ toCommand params
 
 remove :: Key -> Annex Bool
 remove _ = do
 	warning "content cannot be removed from bup remote"
 	return False
 
+{- Cannot revert having stored a key in bup, but at least the data for the
+ - key will be used for deltaing data of other keys stored later.
+ -
+ - We can, however, remove the git branch that bup created for the key.
+ -}
+rollback :: Key -> BupRepo -> Annex ()
+rollback k bupr = go =<< liftIO (bup2GitRemote bupr)
+  where
+	go r
+		| Git.repoIsUrl r = void $ onBupRemote r boolSystem "git" params
+		| otherwise = void $ liftIO $ catchMaybeIO $
+			boolSystem "git" $ Git.Command.gitCommandLine params r
+	params = [ Params "branch -D", Param (bupRef k) ]
+
 {- Bup does not provide a way to tell if a given dataset is present
  - in a bup repository. One way it to check if the git repository has
  - a branch matching the name (as created by bup split -n).
@@ -163,10 +187,11 @@ checkPresent r bupr k
 		return $ Right ok
 	| otherwise = liftIO $ catchMsgIO $
 		boolSystem "git" $ Git.Command.gitCommandLine params bupr
-	where
-		params = 
-			[ Params "show-ref --quiet --verify"
-			, Param $ "refs/heads/" ++ bupRef k]
+  where
+	params = 
+		[ Params "show-ref --quiet --verify"
+		, Param $ "refs/heads/" ++ bupRef k
+		]
 
 {- Store UUID in the annex.uuid setting of the bup repository. -}
 storeBupUUID :: UUID -> BupRepo -> Annex ()
@@ -182,17 +207,23 @@ storeBupUUID u buprepo = do
 			r' <- Git.Config.read r
 			let olduuid = Git.Config.get "annex.uuid" "" r'
 			when (olduuid == "") $
-				Git.Command.run "config"
-					[Param "annex.uuid", Param v] r'
-	where
-		v = fromUUID u
+				Git.Command.run
+					[ Param "config"
+					, Param "annex.uuid"
+					, Param v
+					] r'
+  where
+	v = fromUUID u
 
 onBupRemote :: Git.Repo -> (FilePath -> [CommandParam] -> IO a) -> FilePath -> [CommandParam] -> Annex a
 onBupRemote r a command params = do
-	let dir = shellEscape (Git.repoPath r)
 	sshparams <- sshToRepo r [Param $
 			"cd " ++ dir ++ " && " ++ unwords (command : toCommand params)]
 	liftIO $ a "ssh" sshparams
+  where
+	path = Git.repoPath r
+	base = fromMaybe path (stripPrefix "/~/" path)
+	dir = shellEscape base
 
 {- Allow for bup repositories on removable media by checking
  - local bup repositories to see if they are available, and getting their
@@ -226,17 +257,17 @@ bup2GitRemote r
 			then Git.Construct.fromAbsPath r
 			else error "please specify an absolute path"
 	| otherwise = Git.Construct.fromUrl $ "ssh://" ++ host ++ slash dir
-		where
-			bits = split ":" r
-			host = Prelude.head bits
-			dir = join ":" $ drop 1 bits
-			-- "host:~user/dir" is not supported specially by bup;
-			-- "host:dir" is relative to the home directory;
-			-- "host:" goes in ~/.bup
-			slash d
-				| null d = "/~/.bup"
-				| "/" `isPrefixOf` d = d
-				| otherwise = "/~/" ++ d
+  where
+	bits = split ":" r
+	host = Prelude.head bits
+	dir = intercalate ":" $ drop 1 bits
+	-- "host:~user/dir" is not supported specially by bup;
+	-- "host:dir" is relative to the home directory;
+	-- "host:" goes in ~/.bup
+	slash d
+		| null d = "/~/.bup"
+		| "/" `isPrefixOf` d = d
+		| otherwise = "/~/" ++ d
 
 {- Converts a key into a git ref name, which bup-split -n will use to point
  - to it. -}
@@ -244,8 +275,8 @@ bupRef :: Key -> String
 bupRef k
 	| Git.Ref.legal True shown = shown
 	| otherwise = "git-annex-" ++ showDigest (sha256 (fromString shown))
-	where
-		shown = key2file k
+  where
+	shown = key2file k
 
 bupLocal :: BupRepo -> Bool
 bupLocal = notElem ':'
