@@ -1,6 +1,6 @@
 {- git-annex remote access with ssh
  -
- - Copyright 2011.2012 Joey Hess <joey@kitenet.net>
+ - Copyright 2011,2012 Joey Hess <joey@kitenet.net>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -10,19 +10,22 @@ module Remote.Helper.Ssh where
 import Common.Annex
 import qualified Git
 import qualified Git.Url
-import Config
 import Annex.UUID
 import Annex.Ssh
 import Fields
+import Types.GitConfig
 
 {- Generates parameters to ssh to a repository's host and run a command.
  - Caller is responsible for doing any neccessary shellEscaping of the
  - passed command. -}
 sshToRepo :: Git.Repo -> [CommandParam] -> Annex [CommandParam]
 sshToRepo repo sshcmd = do
-	opts <- map Param . words <$> getRemoteConfig repo "ssh-options" ""
-	params <- sshParams (Git.Url.hostuser repo, Git.Url.port repo) opts
-	return $ params ++ sshcmd
+	g <- fromRepo id
+	let c = extractRemoteGitConfig g (Git.repoDescribe repo)
+	let opts = map Param $ remoteAnnexSshOptions c
+	let host = Git.Url.hostuser repo
+	params <- sshCachingOptions (host, Git.Url.port repo) opts
+	return $ params ++ Param host : sshcmd
 
 {- Generates parameters to run a git-annex-shell command on a remote
  - repository. -}
@@ -34,22 +37,22 @@ git_annex_shell r command params fields
 		sshparams <- sshToRepo r [Param $ sshcmd uuid ]
 		return $ Just ("ssh", sshparams)
 	| otherwise = return Nothing
-	where
-		dir = Git.repoPath r
-		shellcmd = "git-annex-shell"
-		shellopts = Param command : File dir : params
-		sshcmd uuid = unwords $
-			shellcmd : map shellEscape (toCommand shellopts) ++
-			uuidcheck uuid ++
-			map shellEscape (toCommand fieldopts)
-		uuidcheck NoUUID = []
-		uuidcheck (UUID u) = ["--uuid", u]
-		fieldopts
-			| null fields = []
-			| otherwise = fieldsep : map fieldopt fields ++ [fieldsep]
-		fieldsep = Param "--"
-		fieldopt (field, value) = Param $
-			fieldName field ++ "=" ++ value
+  where
+	dir = Git.repoPath r
+	shellcmd = "git-annex-shell"
+	shellopts = Param command : File dir : params
+	sshcmd uuid = unwords $
+		shellcmd : map shellEscape (toCommand shellopts) ++
+		uuidcheck uuid ++
+		map shellEscape (toCommand fieldopts)
+	uuidcheck NoUUID = []
+	uuidcheck (UUID u) = ["--uuid", u]
+	fieldopts
+		| null fields = []
+		| otherwise = fieldsep : map fieldopt fields ++ [fieldsep]
+	fieldsep = Param "--"
+	fieldopt (field, value) = Param $
+		fieldName field ++ "=" ++ value
 
 {- Uses a supplied function (such as boolSystem) to run a git-annex-shell
  - command on a remote.
