@@ -9,6 +9,7 @@
 
 module Types.Key (
 	Key(..),
+	AssociatedFile,
 	stubKey,
 	key2file,
 	file2key,
@@ -21,22 +22,25 @@ import System.Posix.Types
 import Common
 import Utility.QuickCheck
 
-{- A Key has a unique name, is associated with a key/value backend,
+{- A Key has a unique name, which is derived from a particular backend,
  - and may contain other optional metadata. -}
-data Key = Key {
-	keyName :: String,
-	keyBackendName :: String,
-	keySize :: Maybe Integer,
-	keyMtime :: Maybe EpochTime
-} deriving (Eq, Ord, Read, Show)
+data Key = Key
+	{ keyName :: String
+	, keyBackendName :: String
+	, keySize :: Maybe Integer
+	, keyMtime :: Maybe EpochTime
+	} deriving (Eq, Ord, Read, Show)
+
+{- A filename may be associated with a Key. -}
+type AssociatedFile = Maybe FilePath
 
 stubKey :: Key
-stubKey = Key {
-	keyName = "",
-	keyBackendName = "",
-	keySize = Nothing,
-	keyMtime = Nothing
-}
+stubKey = Key
+	{ keyName = ""
+	, keyBackendName = ""
+	, keySize = Nothing
+	, keyMtime = Nothing
+	}
 
 fieldSep :: Char
 fieldSep = '-'
