@@ -5,17 +5,19 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
-{-# LANGUAGE ForeignFunctionInterface #-}
+{-# LANGUAGE ForeignFunctionInterface, CPP #-}
 
 module Utility.DiskFree ( getDiskFree ) where
 
+#ifdef WITH_CLIBS
+
 import Common
 
 import Foreign.C.Types
 import Foreign.C.String
 import Foreign.C.Error
 
-foreign import ccall unsafe "libdiskfree.h diskfree" c_diskfree
+foreign import ccall safe "libdiskfree.h diskfree" c_diskfree
 	:: CString -> IO CULLong
 
 getDiskFree :: FilePath -> IO (Maybe Integer)
@@ -25,5 +27,12 @@ getDiskFree path = withFilePath path $ \c_path -> do
 		( return $ Just $ toInteger free
 		, return Nothing
 		)
-	where
-		safeErrno (Errno v) = v == 0
+  where
+	safeErrno (Errno v) = v == 0
+
+#else
+
+getDiskFree :: FilePath -> IO (Maybe Integer)
+getDiskFree _ = return Nothing
+
+#endif
