@@ -16,11 +16,12 @@ import Data.List
 import Data.Maybe
 import Control.Applicative
 
-#ifdef __WINDOWS__
+#ifdef mingw32_HOST_OS
 import Data.Char
 import qualified System.FilePath.Posix as Posix
 #else
 import qualified "MissingH" System.Path as MissingH
+import System.Posix.Files
 #endif
 
 import Utility.Monad
@@ -37,7 +38,7 @@ import Utility.UserInfo
  - no normalization is done.
  -}
 absNormPath :: FilePath -> FilePath -> Maybe FilePath
-#ifndef __WINDOWS__
+#ifndef mingw32_HOST_OS
 absNormPath dir path = MissingH.absNormPath dir path
 #else
 absNormPath dir path = Just $ combine dir path
@@ -182,7 +183,7 @@ searchPath command
   where
 	indir d = check $ d </> command
 	check f = firstM doesFileExist
-#ifdef __WINDOWS__
+#ifdef mingw32_HOST_OS
 		[f, f ++ ".exe"]
 #else
 		[f]
@@ -202,7 +203,7 @@ dotfile file
 {- Converts a DOS style path to a Cygwin style path. Only on Windows.
  - Any trailing '\' is preserved as a trailing '/' -}
 toCygPath :: FilePath -> FilePath
-#ifndef __WINDOWS__
+#ifndef mingw32_HOST_OS
 toCygPath = id
 #else
 toCygPath p
@@ -217,3 +218,21 @@ toCygPath p
 		| hasTrailingPathSeparator p = Posix.addTrailingPathSeparator s
 		| otherwise = s
 #endif
+
+{- Maximum size to use for a file in a specified directory.
+ -
+ - Many systems have a 255 byte limit to the name of a file, 
+ - so that's taken as the max if the system has a larger limit, or has no
+ - limit.
+ -}
+fileNameLengthLimit :: FilePath -> IO Int
+#ifdef mingw32_HOST_OS
+fileNameLengthLimit _ = return 255
+#else
+fileNameLengthLimit dir = do
+	l <- fromIntegral <$> getPathVar dir FileNameLimit
+	if l <= 0
+		then return 255
+		else return $ minimum [l, 255]
+  where
+#endif
