@@ -22,16 +22,13 @@
 # define STATCALL statfs /* statfs64 not yet tested on a real FreeBSD machine */
 # define STATSTRUCT statfs
 #else
-#if defined (__FreeBSD_kernel__) /* Debian kFreeBSD */
-# include <sys/param.h>
-# include <sys/mount.h>
-# define STATCALL statfs64
-# define STATSTRUCT statfs
-# warning free space checking code temporarily disabled due to build failure
+#if defined __ANDROID__
+# warning free space checking code not available for Android
 # define UNKNOWN
 #else
-#if defined (__linux__)
-/* This is a POSIX standard, so might also work elsewhere. */
+#if defined (__linux__) || defined (__FreeBSD_kernel__)
+/* Linux or Debian kFreeBSD */
+/* This is a POSIX standard, so might also work elsewhere too. */
 # include <sys/statvfs.h>
 # define STATCALL statvfs
 # define STATSTRUCT statvfs
